@@ -2,8 +2,8 @@
  * with multi-lib Linux and OSX/iOS universal builds. To avoid listing all
  * possible architectures here, we try the configured target arch first and then
  * include the most common multilib/universal setups in the #elif ladder */
-#ifdef __x86__
-#include "ffitarget-x86.h"
+#ifdef __x86_64__
+#include "ffitarget-x86_64.h"
 #elif defined(__i386__) || defined(_M_IX86)
 #include "ffitarget-x86.h"
 #elif defined(__x86_64__) || defined(_M_X64)
